@@ -9,11 +9,7 @@
 #ifndef __HSBASE_H__
 #define __HSBASE_H__
 
-#ifdef __NHC__
-# include "Nhc98BaseConfig.h"
-#else
 #include "HsBaseConfig.h"
-#endif
 
 /* ultra-evil... */
 #undef PACKAGE_BUGREPORT
@@ -81,7 +77,7 @@
 #if HAVE_TIME_H
 #include <time.h>
 #endif
-#if HAVE_SYS_TIMEB_H
+#if HAVE_SYS_TIMEB_H && !defined(__FreeBSD__)
 #include <sys/timeb.h>
 #endif
 #if HAVE_WINDOWS_H
@@ -90,7 +86,7 @@
 #if HAVE_SYS_TIMES_H
 #include <sys/times.h>
 #endif
-#if HAVE_WINSOCK_H && defined(__MINGW32__)
+#if HAVE_WINSOCK_H && defined(_WIN32)
 #include <winsock.h>
 #endif
 #if HAVE_LIMITS_H
@@ -104,8 +100,18 @@
 #elif HAVE_STDINT_H
 # include <stdint.h>
 #endif
+#if HAVE_CLOCK_GETTIME
+# ifdef _POSIX_MONOTONIC_CLOCK
+#  define CLOCK_ID CLOCK_MONOTONIC
+# else
+#  define CLOCK_ID CLOCK_REALTIME
+# endif
+#elif defined(darwin_HOST_OS)
+# include <mach/mach.h>
+# include <mach/mach_time.h>
+#endif
 
-#if !defined(__MINGW32__) && !defined(irix_HOST_OS)
+#if !defined(_WIN32)
 # if HAVE_SYS_RESOURCE_H
 #  include <sys/resource.h>
 # endif
@@ -128,13 +134,14 @@
 #endif
 #include "WCsubst.h"
 
-#if defined(__MINGW32__)
+#if defined(_WIN32)
 /* in Win32Utils.c */
 extern void maperrno (void);
-extern HsWord64 getUSecOfDay(void);
+extern int maperrno_func(DWORD dwErrorCode);
+extern HsWord64 getMonotonicUSec(void);
 #endif
 
-#if defined(__MINGW32__)
+#if defined(_WIN32)
 #include <io.h>
 #include <fcntl.h>
 #include <shlobj.h>
@@ -148,9 +155,6 @@ extern HsWord64 getUSecOfDay(void);
 /* in inputReady.c */
 extern int fdReady(int fd, int write, int msecs, int isSock);
 
-/* in Signals.c */
-extern HsInt nocldstop;
-
 /* -----------------------------------------------------------------------------
    INLINE functions.
 
@@ -170,55 +174,12 @@ extern HsInt nocldstop;
 INLINE int __hscore_get_errno(void) { return errno; }
 INLINE void __hscore_set_errno(int e) { errno = e; }
 
-#if !defined(_MSC_VER)
-INLINE int __hscore_s_isreg(mode_t m)  { return S_ISREG(m);  }
-INLINE int __hscore_s_isdir(mode_t m)  { return S_ISDIR(m);  }
-INLINE int __hscore_s_isfifo(mode_t m) { return S_ISFIFO(m); }
-INLINE int __hscore_s_isblk(mode_t m)  { return S_ISBLK(m);  }
-INLINE int __hscore_s_ischr(mode_t m)  { return S_ISCHR(m);  }
-#if !defined(mingw32_HOST_OS) && !defined(__MINGW32__)
-INLINE int __hscore_s_issock(mode_t m) { return S_ISSOCK(m); }
-#endif
-#endif
-
-#if !defined(_MSC_VER) && !defined(__MINGW32__) && !defined(_WIN32)
-INLINE int
-__hscore_sigemptyset( sigset_t *set )
-{ return sigemptyset(set); }
-
-INLINE int
-__hscore_sigfillset( sigset_t *set )
-{ return sigfillset(set); }
-
-INLINE int
-__hscore_sigaddset( sigset_t * set, int s )
-{ return sigaddset(set,s); }
-
-INLINE int
-__hscore_sigdelset( sigset_t * set, int s )
-{ return sigdelset(set,s); }
-
-INLINE int
-__hscore_sigismember( sigset_t * set, int s )
-{ return sigismember(set,s); }
-#endif
-
-INLINE void *
-__hscore_memcpy_src_off( char *dst, char *src, int src_off, size_t sz )
-{ return memcpy(dst, src+src_off, sz); }
-
 INLINE HsInt
 __hscore_bufsiz(void)
 {
   return BUFSIZ;
 }
 
-INLINE int
-__hscore_seek_cur(void)
-{
-  return SEEK_CUR;
-}
-
 INLINE int
 __hscore_o_binary(void)
 {
@@ -319,18 +280,6 @@ __hscore_o_nonblock( void )
 #endif
 }
 
-INLINE int
-__hscore_seek_set( void )
-{
-  return SEEK_SET;
-}
-
-INLINE int
-__hscore_seek_end( void )
-{
-  return SEEK_END;
-}
-
 INLINE int
 __hscore_ftruncate( int fd, off_t where )
 {
@@ -349,18 +298,14 @@ __hscore_ftruncate( int fd, off_t where )
 INLINE int
 __hscore_setmode( int fd, HsBool toBin )
 {
-#if defined(_MSC_VER) || defined(__MINGW32__) || defined(_WIN32)
-  return setmode(fd,(toBin == HS_BOOL_TRUE) ? _O_BINARY : _O_TEXT);
+#if defined(_WIN32)
+  return _setmode(fd,(toBin == HS_BOOL_TRUE) ? _O_BINARY : _O_TEXT);
 #else
   return 0;
 #endif
 }
 
-#if __GLASGOW_HASKELL__
-
-#endif /* __GLASGOW_HASKELL__ */
-
-#if defined(__MINGW32__)
+#if defined(_WIN32)
 // We want the versions of stat/fstat/lseek that use 64-bit offsets,
 // and you have to ask for those explicitly.  Unfortunately there
 // doesn't seem to be a 64-bit version of truncate/ftruncate, so while
@@ -386,7 +331,7 @@ INLINE dev_t  __hscore_st_dev  ( struct_stat* st ) { return st->st_dev; }
 INLINE ino_t  __hscore_st_ino  ( struct_stat* st ) { return st->st_ino; }
 #endif
 
-#if defined(__MINGW32__)
+#if defined(_WIN32)
 INLINE int __hscore_stat(wchar_t *file, struct_stat *buf) {
 	return _wstati64(file,buf);
 }
@@ -430,7 +375,7 @@ __hscore_ptr_c_cc( struct termios* ts )
 INLINE HsInt
 __hscore_sizeof_termios( void )
 {
-#ifndef __MINGW32__
+#ifndef _WIN32
   return sizeof(struct termios);
 #else
   return 0;
@@ -438,7 +383,7 @@ __hscore_sizeof_termios( void )
 }
 #endif
 
-#if !defined(_MSC_VER) && !defined(__MINGW32__) && !defined(_WIN32)
+#if !defined(_WIN32)
 INLINE HsInt
 __hscore_sizeof_sigset_t( void )
 {
@@ -523,7 +468,7 @@ INLINE int __hscore_sig_setmask( void )
 #endif
 }
 
-#ifndef __MINGW32__
+#ifndef _WIN32
 INLINE size_t __hscore_sizeof_siginfo_t (void)
 {
     return sizeof(siginfo_t);
@@ -574,15 +519,13 @@ __hscore_fd_cloexec( void )
 extern void* __hscore_get_saved_termios(int fd);
 extern void __hscore_set_saved_termios(int fd, void* ts);
 
-INLINE int __hscore_hs_fileno (FILE *f) { return fileno (f); }
-
-#ifdef __MINGW32__
+#ifdef _WIN32
 INLINE int __hscore_open(wchar_t *file, int how, mode_t mode) {
 	if ((how & O_WRONLY) || (how & O_RDWR) || (how & O_APPEND))
-	  return _wsopen(file,how | _O_NOINHERIT,_SH_DENYRW,mode);
+	  return _wsopen(file,how | _O_NOINHERIT,_SH_DENYNO,mode);
           // _O_NOINHERIT: see #2650
 	else
-	  return _wsopen(file,how | _O_NOINHERIT,_SH_DENYWR,mode);
+	  return _wsopen(file,how | _O_NOINHERIT,_SH_DENYNO,mode);
           // _O_NOINHERIT: see #2650
 }
 #else
@@ -591,35 +534,6 @@ INLINE int __hscore_open(char *file, int how, mode_t mode) {
 }
 #endif
 
-// These are wrapped because on some OSs (eg. Linux) they are
-// macros which redirect to the 64-bit-off_t versions when large file
-// support is enabled.
-//
-#if defined(__MINGW32__)
-INLINE off64_t __hscore_lseek(int fd, off64_t off, int whence) {
-	return (_lseeki64(fd,off,whence));
-}
-#else
-INLINE off_t __hscore_lseek(int fd, off_t off, int whence) {
-	return (lseek(fd,off,whence));
-}
-#endif
-
-// select-related stuff
-
-#if !defined(__MINGW32__)
-INLINE int  hsFD_SETSIZE(void) { return FD_SETSIZE; }
-INLINE int  hsFD_ISSET(int fd, fd_set *fds) { return FD_ISSET(fd, fds); }
-INLINE void hsFD_SET(int fd, fd_set *fds) { FD_SET(fd, fds); }
-INLINE HsInt sizeof_fd_set(void) { return sizeof(fd_set); }
-extern void hsFD_ZERO(fd_set *fds);
-#endif
-
-INLINE int __hscore_select(int nfds, fd_set *readfds, fd_set *writefds,
-                           fd_set *exceptfds, struct timeval *timeout) {
-	return (select(nfds,readfds,writefds,exceptfds,timeout));
-}
-
 #if darwin_HOST_OS
 // You should not access _environ directly on Darwin in a bundle/shared library.
 // See #2458 and http://developer.apple.com/library/mac/#documentation/Darwin/Reference/ManPages/man7/environ.7.html
