@@ -7,27 +7,25 @@
  * Do not #include this file directly: #include "Rts.h" instead.
  *
  * To understand the structure of the RTS headers, see the wiki:
- *   http://hackage.haskell.org/trac/ghc/wiki/Commentary/SourceTree/Includes
+ *   http://ghc.haskell.org/trac/ghc/wiki/Commentary/SourceTree/Includes
  *
  * ---------------------------------------------------------------------------*/
 
 #ifndef RTS_TYPES_H
 #define RTS_TYPES_H
 
-typedef unsigned int  nat;           /* at least 32 bits (like int) */
-typedef unsigned long lnat;          /* at least 32 bits            */
+#include <stddef.h>
+#include <stdbool.h>
+
+// Deprecated, use uint32_t instead.
+typedef unsigned int nat __attribute__((deprecated));  /* uint32_t */
 
 /* ullong (64|128-bit) type: only include if needed (not ANSI) */
-#if defined(__GNUC__) 
+#if defined(__GNUC__)
 #define LL(x) (x##LL)
 #else
 #define LL(x) (x##L)
 #endif
-  
-typedef enum { 
-    rtsFalse = 0, 
-    rtsTrue 
-} rtsBool;
 
 typedef struct StgClosure_   StgClosure;
 typedef struct StgInfoTable_ StgInfoTable;
